### Entering Text

Edit View can display multiple glyphs to provide a context of words and sentences.

Tip:

Quickly switch between text entry and editing the current glyph by pressing the Escape key.

When using the Text tool (T), enter characters using the keyboard.
Insert non-alphabetic characters with the Character Picker (“Edit” → “Emoji & Symbols”, Cmd-Ctrl-Space).
Edit View has a preset line width.
Set the maximum line width in the settings.

#### Text Tool

Select the Text tool  (shortcut T) to switch to text mode and start typing.
Enter a single character, a word, a sentence, or multiple lines of text.
Copy and paste text to and from Edit View.
Use all familiar text editing controls such as the arrow keys, the “Edit” menu, and macOS Application Services (“Glyphs” → “Services”).
In text mode, the current glyph is the one after the text cursor.

##### Find Glyphs to Insert

Insert a glyph by name with “Edit” → “Find” → “Find…” (Cmd-F).
Results are shown while typing.
If the search term contains spaces, glyphs matching all the space-separated terms will be shown.
For example, “ha cy” will find all glyphs that have “ha” and “cy” in their name, such as Ha-cy, Sha-cy, and sha-cy.loclBGR.
Use a Unicode character as a search term to insert its glyph (or type the character directly into Edit View).

Press Return to insert the selected glyphs into Edit View.
By default, the first result is selected.
Shift-click to select a range of results, or Command-click to select results individually.

Click the magnifying glass  to configure the search.
Choose “Name” to search by glyph name, “Unicode” to search by Unicode value, and “All” to search by both.
The Unicode search matches the entered search query with the hexadecimal Unicode values of the glyphs (for example, “228E”).

##### Change the Current Glyph

Tip:

On keyboards without Home and End keys, press Fn-Left Arrow and Fn-Right Arrow.

Switch to the previous or next glyph in the font by pressing the Home and End key, respectively.
Add Shift to advance through the glyphs as they are currently visible in the Font View.
These shortcuts are useful when filtering glyphs in the Font View and stepping through them in Edit View.

##### Placeholder Glyphs

“Edit” → “Add Placeholder” (Cmd-Opt-Shift-P) inserts a placeholder for the current glyph.
Placeholders are dynamically replaced by the currently selected glyph.
Multiple placeholders can be placed in Edit View to all reflect the same glyph.
Edit a glyph for all placeholders to mirror it.
Placeholders are helpful when spacing a glyph; for example, quickly switch from “ononnoon” to “omommoom” if the n glyphs are placeholders.

#### Writing Direction

Switch between left to right, right to left, and top to bottom layout with the respective alignment buttons in the bottom-right corner of the Edit View window.

#### Text Preview

Keeping a lot of text in Edit View will slow down the interface.
Instead, use the Text Preview (“Window” → “Text Preview”) for reviewing longer passages of text.

Tip:

The Text Preview performs well with any amount of text, even the contents of an entire book.

Enter text in the text field.
This text field renders a real preview of the font using the Core Text shaping engine by Apple, just like most other Mac apps do.
Note that characters unsupported by the font are displayed using a system fallback font.

Control-click or right-click into the text field and choose “Layout Orientation” → “Vertical” to switch to a vertical text layout.
Also from the context menu, use the “Writing Direction” submenu to control the direction of the text and the text selection.

Choose “Edit” → “Find” → “Find…” (Cmd-F) to search for text or replace text in the text field.
Click the magnifying glass  icon to set options for the search.
Choose “Insert Pattern” or press Cmd-Opt-Ctrl-P to search for patterns such as spaces or digits.

Use the pop-up menu in the top-left of the window to pick the preview font style.
The field to the right controls the font size at which the text preview is displayed.
Click the pin  icon to toggle the pinned state of the window.
A pinned window stays on top of the font window, allowing to continue editing glyphs while still keeping an eye on the text preview.

#### Sample Strings

Edit and store sample strings in “Glyphs” → “Settings…” → “Sample Strings”.
Insert a sample string by choosing “Edit” → “Select Sample Text…” (Cmd-Opt-F).
Use the arrow keys or click to choose a string.

Switch to the next or previous sample string without the dialog by choosing “Edit” → “Other” → “Select Next Sample String” or “Select Previous Sample String”, respectively.
Keyboard shortcuts to these commands can be assigned in the settings.
Click the pin  button to keep the sample strings window open.